@@ -47,6 +47,7 @@ my %hierarchy = (
     'AlphaReplaceEffect' => 'ImageTransformEffect',
     'ArcToPathSegment' => 'PathSegment',
     'ArrayElement' => 'MathElement',
+    'AudioFrame' => 'GeometryShape',
     'BarElement' => 'MathElement',
     'Base64InputFile' => 'InputFile',
     'BiLevelEffect' => 'ImageTransformEffect',
@@ -54,15 +55,20 @@ my %hierarchy = (
     'BlurImageEffect' => 'ImageTransformEffect',
     'BorderBoxElement' => 'MathElement',
     'BoxElement' => 'MathElement',
+    'BubbleChartDataPoint' => 'ScatterChartDataPoint',
+    'BubbleSeries' => 'XYSeries',
+    'Chart' => 'ShapeBase',
     'ClosePathSegment' => 'PathSegment',
     'ColorChangeEffect' => 'ImageTransformEffect',
     'ColorReplaceEffect' => 'ImageTransformEffect',
     'ColorScheme' => 'ResourceBase',
+    'Connector' => 'GeometryShape',
     'CubicBezierToPathSegment' => 'PathSegment',
     'DelimiterElement' => 'MathElement',
     'Document' => 'ResourceBase',
     'DocumentProperties' => 'ResourceBase',
     'DocumentProperty' => 'ResourceBase',
+    'DocumentReplaceResult' => 'Document',
     'DuotoneEffect' => 'ImageTransformEffect',
     'FileVersion' => 'StorageFile',
     'FillOverlayImageEffect' => 'ImageTransformEffect',
@@ -70,14 +76,19 @@ my %hierarchy = (
     'FormatScheme' => 'ResourceBase',
     'FractionElement' => 'MathElement',
     'FunctionElement' => 'MathElement',
+    'GeometryShape' => 'ShapeBase',
+    'GifExportOptions' => 'ImageExportOptionsBase',
     'GradientFill' => 'FillFormat',
+    'GraphicalObject' => 'ShapeBase',
     'GrayScaleEffect' => 'ImageTransformEffect',
+    'GroupShape' => 'ShapeBase',
     'GroupingCharacterElement' => 'MathElement',
     'HeaderFooter' => 'ResourceBase',
     'HslEffect' => 'ImageTransformEffect',
     'Html5ExportOptions' => 'ExportOptions',
     'HtmlExportOptions' => 'ExportOptions',
     'Image' => 'ResourceBase',
+    'ImageExportOptions' => 'ImageExportOptionsBase',
     'ImageExportOptionsBase' => 'ExportOptions',
     'Images' => 'ResourceBase',
     'LayoutSlide' => 'ResourceBase',
@@ -85,6 +96,7 @@ my %hierarchy = (
     'LeftSubSuperscriptElement' => 'MathElement',
     'LimitElement' => 'MathElement',
     'LineToPathSegment' => 'PathSegment',
+    'Literals' => 'DataSource',
     'LuminanceEffect' => 'ImageTransformEffect',
     'MasterSlide' => 'ResourceBase',
     'MasterSlides' => 'ResourceBase',
@@ -95,6 +107,7 @@ my %hierarchy = (
     'NoFill' => 'FillFormat',
     'NotesSlide' => 'ResourceBase',
     'NotesSlideHeaderFooter' => 'ResourceBase',
+    'OleObjectFrame' => 'ShapeBase',
     'OneValueChartDataPoint' => 'DataPoint',
     'OneValueSeries' => 'Series',
     'Paragraph' => 'ResourceBase',
@@ -104,6 +117,7 @@ my %hierarchy = (
     'PatternFill' => 'FillFormat',
     'PdfExportOptions' => 'ExportOptions',
     'PictureFill' => 'FillFormat',
+    'PictureFrame' => 'GeometryShape',
     'Placeholder' => 'ResourceBase',
     'Placeholders' => 'ResourceBase',
     'Portion' => 'ResourceBase',
@@ -124,8 +138,11 @@ my %hierarchy = (
     'SaveShape' => 'Task',
     'SaveSlide' => 'Task',
     'ScatterChartDataPoint' => 'DataPoint',
+    'ScatterSeries' => 'XYSeries',
     'Section' => 'ResourceBase',
+    'SectionZoomFrame' => 'ZoomObject',
     'Sections' => 'ResourceBase',
+    'Shape' => 'GeometryShape',
     'ShapeBase' => 'ResourceBase',
     'Shapes' => 'ResourceBase',
     'Slide' => 'ResourceBase',
@@ -135,148 +152,42 @@ my %hierarchy = (
     'SlideComments' => 'ResourceBase',
     'SlideModernComment' => 'SlideCommentBase',
     'SlideProperties' => 'ResourceBase',
+    'SlideReplaceResult' => 'Slide',
     'SlideShowProperties' => 'ResourceBase',
     'Slides' => 'ResourceBase',
+    'SmartArt' => 'ShapeBase',
+    'SmartArtShape' => 'GeometryShape',
     'SolidFill' => 'FillFormat',
     'SplitDocumentResult' => 'ResourceBase',
     'SubscriptElement' => 'MathElement',
+    'SummaryZoomFrame' => 'ShapeBase',
+    'SummaryZoomSection' => 'SectionZoomFrame',
     'SuperscriptElement' => 'MathElement',
     'SvgExportOptions' => 'ExportOptions',
     'SwfExportOptions' => 'ExportOptions',
+    'Table' => 'ShapeBase',
     'TextElement' => 'MathElement',
     'TextItems' => 'ResourceBase',
     'Theme' => 'ResourceBase',
+    'TiffExportOptions' => 'ImageExportOptionsBase',
     'TintEffect' => 'ImageTransformEffect',
     'UpdateBackground' => 'Task',
     'UpdateShape' => 'Task',
     'VideoExportOptions' => 'ExportOptions',
+    'VideoFrame' => 'GeometryShape',
     'ViewProperties' => 'ResourceBase',
+    'Workbook' => 'DataSource',
     'XYSeries' => 'Series',
     'XamlExportOptions' => 'ExportOptions',
     'XpsExportOptions' => 'ExportOptions',
-    'BubbleChartDataPoint' => 'ScatterChartDataPoint',
-    'BubbleSeries' => 'XYSeries',
-    'Chart' => 'ShapeBase',
-    'DocumentReplaceResult' => 'Document',
-    'GeometryShape' => 'ShapeBase',
-    'GifExportOptions' => 'ImageExportOptionsBase',
-    'GraphicalObject' => 'ShapeBase',
-    'GroupShape' => 'ShapeBase',
-    'ImageExportOptions' => 'ImageExportOptionsBase',
-    'OleObjectFrame' => 'ShapeBase',
-    'ScatterSeries' => 'XYSeries',
-    'SlideReplaceResult' => 'Slide',
-    'SmartArt' => 'ShapeBase',
-    'SummaryZoomFrame' => 'ShapeBase',
-    'Table' => 'ShapeBase',
-    'TiffExportOptions' => 'ImageExportOptionsBase',
-    'ZoomObject' => 'ShapeBase',
-    'AudioFrame' => 'GeometryShape',
-    'Connector' => 'GeometryShape',
-    'PictureFrame' => 'GeometryShape',
-    'SectionZoomFrame' => 'ZoomObject',
-    'Shape' => 'GeometryShape',
-    'SmartArtShape' => 'GeometryShape',
-    'VideoFrame' => 'GeometryShape',
     'ZoomFrame' => 'ZoomObject',
-    'SummaryZoomSection' => 'SectionZoomFrame',
+    'ZoomObject' => 'ShapeBase',
     
 );
 
 my %determiners = (
-    'AccessPermissions' => {  },
-    'ApiInfo' => {  },
-    'ArrowHeadProperties' => {  },
-    'Axes' => {  },
-    'Axis' => {  },
-    'AxisType' => {  },
-    'BlurEffect' => {  },
-    'Camera' => {  },
-    'ChartCategory' => {  },
-    'ChartLinesFormat' => {  },
-    'ChartSeriesGroup' => {  },
-    'ChartTitle' => {  },
-    'ChartWall' => {  },
-    'ChartWallType' => {  },
-    'CommonSlideViewProperties' => {  },
-    'CustomDashPattern' => {  },
-    'DataPoint' => {  },
-    'DiscUsage' => {  },
-    'Effect' => {  },
-    'EffectFormat' => {  },
-    'EntityExists' => {  },
-    'Error' => {  },
-    'ErrorDetails' => {  },
-    'ExportFormat' => {  },
-    'ExportOptions' => {  },
-    'FileVersions' => {  },
-    'FilesList' => {  },
-    'FilesUploadResult' => {  },
-    'FillFormat' => {  },
-    'FillOverlayEffect' => {  },
-    'FontData' => {  },
-    'FontFallbackRule' => {  },
-    'FontSet' => {  },
-    'FontSubstRule' => {  },
-    'FontsData' => {  },
-    'GeometryPath' => {  },
-    'GeometryPaths' => {  },
-    'GlowEffect' => {  },
-    'GradientFillStop' => {  },
-    'Hyperlink' => {  },
-    'IShapeExportOptions' => {  },
-    'ImageExportFormat' => {  },
-    'ImageTransformEffect' => {  },
-    'InnerShadowEffect' => {  },
-    'Input' => {  },
-    'InputFile' => {  },
-    'InteractiveSequence' => {  },
-    'Legend' => {  },
-    'LightRig' => {  },
-    'LineFormat' => {  },
-    'MathElement' => {  },
-    'MathParagraph' => {  },
-    'MergingSource' => {  },
-    'NormalViewRestoredProperties' => {  },
-    'NotesSlideExportFormat' => {  },
-    'ObjectExist' => {  },
-    'OrderedMergeRequest' => {  },
-    'OuterShadowEffect' => {  },
-    'OutputFile' => {  },
-    'PathSegment' => {  },
-    'Pipeline' => {  },
-    'PlotArea' => {  },
-    'PortionFormat' => {  },
-    'PresentationToMerge' => {  },
-    'PresentationsMergeRequest' => {  },
-    'PresetShadowEffect' => {  },
-    'ReflectionEffect' => {  },
-    'ResourceBase' => {  },
-    'ResourceUri' => {  },
-    'Series' => {  },
-    'SeriesMarker' => {  },
-    'ShapeBevel' => {  },
-    'ShapeExportFormat' => {  },
-    'ShapeImageExportOptions' => {  },
-    'ShapeThumbnailBounds' => {  },
-    'ShapeType' => {  },
-    'ShapesAlignmentType' => {  },
-    'SlideCommentBase' => {  },
-    'SlideExportFormat' => {  },
-    'SmartArtNode' => {  },
-    'SoftEdgeEffect' => {  },
-    'SpecialSlideType' => {  },
-    'StorageExist' => {  },
-    'StorageFile' => {  },
-    'TableCell' => {  },
-    'TableColumn' => {  },
-    'TableRow' => {  },
-    'Task' => {  },
-    'TextBounds' => {  },
-    'TextFrameFormat' => {  },
-    'TextItem' => {  },
-    'ThreeDFormat' => {  },
     'AccentElement' => { 'Type' => 'Accent', },
+    'AccessPermissions' => {  },
     'AddLayoutSlide' => { 'Type' => 'AddLayoutSlide', },
     'AddMasterSlide' => { 'Type' => 'AddMasterSlide', },
     'AddShape' => { 'Type' => 'AddShape', },
@@ -288,141 +199,235 @@ my %determiners = (
     'AlphaModulateEffect' => { 'Type' => 'AlphaModulate', },
     'AlphaModulateFixedEffect' => { 'Type' => 'AlphaModulateFixed', },
     'AlphaReplaceEffect' => { 'Type' => 'AlphaReplace', },
+    'ApiInfo' => {  },
     'ArcToPathSegment' => { 'Type' => 'ArcTo', },
     'ArrayElement' => { 'Type' => 'Array', },
+    'ArrowHeadProperties' => {  },
+    'AudioFrame' => { 'Type' => 'AudioFrame', },
+    'Axes' => {  },
+    'Axis' => {  },
+    'AxisType' => {  },
     'BarElement' => { 'Type' => 'Bar', },
     'Base64InputFile' => { 'Type' => 'Base64', },
     'BiLevelEffect' => { 'Type' => 'BiLevel', },
     'BlockElement' => { 'Type' => 'Block', },
+    'BlurEffect' => {  },
     'BlurImageEffect' => { 'Type' => 'Blur', },
     'BorderBoxElement' => { 'Type' => 'BorderBox', },
     'BoxElement' => { 'Type' => 'Box', },
+    'BubbleChartDataPoint' => {  },
+    'BubbleSeries' => { 'DataPointType' => 'Bubble', },
+    'Camera' => {  },
+    'Chart' => { 'Type' => 'Chart', },
+    'ChartCategory' => {  },
+    'ChartLinesFormat' => {  },
+    'ChartSeriesGroup' => {  },
+    'ChartTitle' => {  },
+    'ChartWall' => {  },
+    'ChartWallType' => {  },
     'ClosePathSegment' => { 'Type' => 'Close', },
     'ColorChangeEffect' => { 'Type' => 'ColorChange', },
     'ColorReplaceEffect' => { 'Type' => 'ColorReplace', },
     'ColorScheme' => {  },
+    'CommonSlideViewProperties' => {  },
+    'Connector' => { 'Type' => 'Connector', },
     'CubicBezierToPathSegment' => { 'Type' => 'CubicBezierTo', },
+    'CustomDashPattern' => {  },
+    'DataPoint' => {  },
+    'DataSource' => {  },
     'DelimiterElement' => { 'Type' => 'Delimiter', },
+    'DiscUsage' => {  },
     'Document' => {  },
     'DocumentProperties' => {  },
     'DocumentProperty' => {  },
+    'DocumentReplaceResult' => {  },
     'DuotoneEffect' => { 'Type' => 'Duotone', },
+    'Effect' => {  },
+    'EffectFormat' => {  },
+    'EntityExists' => {  },
+    'Error' => {  },
+    'ErrorDetails' => {  },
+    'ExportFormat' => {  },
+    'ExportOptions' => {  },
     'FileVersion' => {  },
+    'FileVersions' => {  },
+    'FilesList' => {  },
+    'FilesUploadResult' => {  },
+    'FillFormat' => {  },
+    'FillOverlayEffect' => {  },
     'FillOverlayImageEffect' => { 'Type' => 'FillOverlay', },
+    'FontData' => {  },
+    'FontFallbackRule' => {  },
     'FontScheme' => {  },
+    'FontSet' => {  },
+    'FontSubstRule' => {  },
+    'FontsData' => {  },
     'FormatScheme' => {  },
     'FractionElement' => { 'Type' => 'Fraction', },
     'FunctionElement' => { 'Type' => 'Function', },
+    'GeometryPath' => {  },
+    'GeometryPaths' => {  },
+    'GeometryShape' => {  },
+    'GifExportOptions' => { 'Format' => 'gif', },
+    'GlowEffect' => {  },
     'GradientFill' => { 'Type' => 'Gradient', },
+    'GradientFillStop' => {  },
+    'GraphicalObject' => { 'Type' => 'GraphicalObject', },
     'GrayScaleEffect' => { 'Type' => 'GrayScale', },
+    'GroupShape' => { 'Type' => 'GroupShape', },
     'GroupingCharacterElement' => { 'Type' => 'GroupingCharacter', },
     'HeaderFooter' => {  },
     'HslEffect' => { 'Type' => 'Hsl', },
     'Html5ExportOptions' => { 'Format' => 'html5', },
     'HtmlExportOptions' => { 'Format' => 'html', },
+    'Hyperlink' => {  },
+    'IShapeExportOptions' => {  },
     'Image' => {  },
+    'ImageExportFormat' => {  },
+    'ImageExportOptions' => { 'Format' => 'image', },
     'ImageExportOptionsBase' => {  },
+    'ImageTransformEffect' => {  },
     'Images' => {  },
+    'InnerShadowEffect' => {  },
+    'Input' => {  },
+    'InputFile' => {  },
+    'InteractiveSequence' => {  },
     'LayoutSlide' => {  },
     'LayoutSlides' => {  },
     'LeftSubSuperscriptElement' => { 'Type' => 'LeftSubSuperscriptElement', },
+    'Legend' => {  },
+    'LightRig' => {  },
     'LimitElement' => { 'Type' => 'Limit', },
+    'LineFormat' => {  },
     'LineToPathSegment' => { 'Type' => 'LineTo', },
+    'Literals' => { 'Type' => 'Literals', },
     'LuminanceEffect' => { 'Type' => 'Luminance', },
     'MasterSlide' => {  },
     'MasterSlides' => {  },
+    'MathElement' => {  },
+    'MathParagraph' => {  },
     'MatrixElement' => { 'Type' => 'Matrix', },
     'Merge' => { 'Type' => 'Merge', },
+    'MergingSource' => {  },
     'MoveToPathSegment' => { 'Type' => 'MoveTo', },
     'NaryOperatorElement' => { 'Type' => 'NaryOperator', },
     'NoFill' => { 'Type' => 'NoFill', },
+    'NormalViewRestoredProperties' => {  },
     'NotesSlide' => {  },
+    'NotesSlideExportFormat' => {  },
     'NotesSlideHeaderFooter' => {  },
+    'ObjectExist' => {  },
+    'OleObjectFrame' => { 'Type' => 'OleObjectFrame', },
     'OneValueChartDataPoint' => {  },
     'OneValueSeries' => { 'DataPointType' => 'OneValue', },
+    'OrderedMergeRequest' => {  },
+    'OuterShadowEffect' => {  },
+    'OutputFile' => {  },
     'Paragraph' => {  },
     'Paragraphs' => {  },
     'PathInputFile' => { 'Type' => 'Path', },
     'PathOutputFile' => { 'Type' => 'Path', },
+    'PathSegment' => {  },
     'PatternFill' => { 'Type' => 'Pattern', },
     'PdfExportOptions' => { 'Format' => 'pdf', },
     'PictureFill' => { 'Type' => 'Picture', },
+    'PictureFrame' => { 'Type' => 'PictureFrame', },
+    'Pipeline' => {  },
     'Placeholder' => {  },
     'Placeholders' => {  },
+    'PlotArea' => {  },
     'Portion' => {  },
+    'PortionFormat' => {  },
     'Portions' => {  },
     'PptxExportOptions' => { 'Format' => 'pptx', },
+    'PresentationToMerge' => {  },
+    'PresentationsMergeRequest' => {  },
+    'PresetShadowEffect' => {  },
     'ProtectionProperties' => {  },
     'QuadraticBezierToPathSegment' => { 'Type' => 'QuadBezierTo', },
     'RadicalElement' => { 'Type' => 'Radical', },
+    'ReflectionEffect' => {  },
     'RemoveShape' => { 'Type' => 'RemoveShape', },
     'RemoveSlide' => { 'Type' => 'RemoveSlide', },
     'ReorderSlide' => { 'Type' => 'ReoderSlide', },
     'ReplaceText' => { 'Type' => 'ReplaceText', },
     'RequestInputFile' => { 'Type' => 'Request', },
     'ResetSlide' => { 'Type' => 'ResetSlide', },
+    'ResourceBase' => {  },
+    'ResourceUri' => {  },
     'ResponseOutputFile' => { 'Type' => 'Response', },
     'RightSubSuperscriptElement' => { 'Type' => 'RightSubSuperscriptElement', },
     'Save' => { 'Type' => 'Save', },
     'SaveShape' => { 'Type' => 'SaveShape', },
     'SaveSlide' => { 'Type' => 'SaveSlide', },
     'ScatterChartDataPoint' => {  },
+    'ScatterSeries' => { 'DataPointType' => 'Scatter', },
     'Section' => {  },
+    'SectionZoomFrame' => { 'Type' => 'SectionZoomFrame', },
     'Sections' => {  },
+    'Series' => {  },
+    'SeriesMarker' => {  },
+    'Shape' => { 'Type' => 'Shape', },
     'ShapeBase' => {  },
+    'ShapeBevel' => {  },
+    'ShapeExportFormat' => {  },
+    'ShapeImageExportOptions' => {  },
+    'ShapeThumbnailBounds' => {  },
+    'ShapeType' => {  },
     'Shapes' => {  },
+    'ShapesAlignmentType' => {  },
     'Slide' => {  },
     'SlideAnimation' => {  },
     'SlideBackground' => {  },
     'SlideComment' => { 'Type' => 'Regular', },
+    'SlideCommentBase' => {  },
     'SlideComments' => {  },
+    'SlideExportFormat' => {  },
     'SlideModernComment' => { 'Type' => 'Modern', },
     'SlideProperties' => {  },
+    'SlideReplaceResult' => {  },
     'SlideShowProperties' => {  },
     'Slides' => {  },
+    'SmartArt' => { 'Type' => 'SmartArt', },
+    'SmartArtNode' => {  },
+    'SmartArtShape' => { 'Type' => 'SmartArtShape', },
+    'SoftEdgeEffect' => {  },
     'SolidFill' => { 'Type' => 'Solid', },
+    'SpecialSlideType' => {  },
     'SplitDocumentResult' => {  },
+    'StorageExist' => {  },
+    'StorageFile' => {  },
     'SubscriptElement' => { 'Type' => 'SubscriptElement', },
+    'SummaryZoomFrame' => { 'Type' => 'SummaryZoomFrame', },
+    'SummaryZoomSection' => { 'Type' => 'SummaryZoomSection', },
     'SuperscriptElement' => { 'Type' => 'SuperscriptElement', },
     'SvgExportOptions' => { 'Format' => 'svg', },
     'SwfExportOptions' => { 'Format' => 'swf', },
+    'Table' => { 'Type' => 'Table', },
+    'TableCell' => {  },
+    'TableColumn' => {  },
+    'TableRow' => {  },
+    'Task' => {  },
+    'TextBounds' => {  },
     'TextElement' => { 'Type' => 'Text', },
+    'TextFrameFormat' => {  },
+    'TextItem' => {  },
     'TextItems' => {  },
     'Theme' => {  },
+    'ThreeDFormat' => {  },
+    'TiffExportOptions' => { 'Format' => 'tiff', },
     'TintEffect' => { 'Type' => 'Tint', },
     'UpdateBackground' => { 'Type' => 'UpdateBackground', },
     'UpdateShape' => { 'Type' => 'UpdateShape', },
     'VideoExportOptions' => { 'Format' => 'mpeg4', },
+    'VideoFrame' => { 'Type' => 'VideoFrame', },
     'ViewProperties' => {  },
+    'Workbook' => { 'Type' => 'Workbook', },
     'XYSeries' => {  },
     'XamlExportOptions' => { 'Format' => 'xaml', },
     'XpsExportOptions' => { 'Format' => 'xps', },
-    'BubbleChartDataPoint' => {  },
-    'BubbleSeries' => { 'DataPointType' => 'Bubble', },
-    'Chart' => { 'Type' => 'Chart', },
-    'DocumentReplaceResult' => {  },
-    'GeometryShape' => {  },
-    'GifExportOptions' => { 'Format' => 'gif', },
-    'GraphicalObject' => { 'Type' => 'GraphicalObject', },
-    'GroupShape' => { 'Type' => 'GroupShape', },
-    'ImageExportOptions' => { 'Format' => 'image', },
-    'OleObjectFrame' => { 'Type' => 'OleObjectFrame', },
-    'ScatterSeries' => { 'DataPointType' => 'Scatter', },
-    'SlideReplaceResult' => {  },
-    'SmartArt' => { 'Type' => 'SmartArt', },
-    'SummaryZoomFrame' => { 'Type' => 'SummaryZoomFrame', },
-    'Table' => { 'Type' => 'Table', },
-    'TiffExportOptions' => { 'Format' => 'tiff', },
-    'ZoomObject' => {  },
-    'AudioFrame' => { 'Type' => 'AudioFrame', },
-    'Connector' => { 'Type' => 'Connector', },
-    'PictureFrame' => { 'Type' => 'PictureFrame', },
-    'SectionZoomFrame' => { 'Type' => 'SectionZoomFrame', },
-    'Shape' => { 'Type' => 'Shape', },
-    'SmartArtShape' => { 'Type' => 'SmartArtShape', },
-    'VideoFrame' => { 'Type' => 'VideoFrame', },
     'ZoomFrame' => { 'Type' => 'ZoomFrame', },
-    'SummaryZoomSection' => { 'Type' => 'SummaryZoomSection', },
+    'ZoomObject' => {  },
 );
 
 sub is_subclass {
